package com.gxzc.zen.api.sys.service.impl

import com.baomidou.mybatisplus.mapper.EntityWrapper
import com.baomidou.mybatisplus.service.impl.ServiceImpl
import com.gxzc.zen.api.sys.mapper.SysUploadInfoMapper
import com.gxzc.zen.api.sys.model.SysUploadInfo
import com.gxzc.zen.api.sys.service.ISysUploadInfoService
import com.gxzc.zen.common.dto.ZenFileMetadata
import com.gxzc.zen.common.util.PlatformUtil
import org.apache.commons.io.FilenameUtils
import org.springframework.stereotype.Service
import java.io.File
import java.util.*

/**
 * <p>
 * 上传文件信息表 服务实现类
 * </p>
 *
 * @author NorthLan
 * @since 2018-06-01
 */
@Service
class SysUploadInfoServiceImpl : ServiceImpl<SysUploadInfoMapper, SysUploadInfo>(), ISysUploadInfoService {
    override fun addUploadFile(fileMetadata: ZenFileMetadata, file: File) {
        val entity = SysUploadInfo().apply {
            this.platformId = PlatformUtil.getPlatformId()
            this.batchId = fileMetadata.batchId
            this.originFilename = fileMetadata.filename
            this.originRelativePath = fileMetadata.relativePath?.replace(this.originFilename!!, "")
            this.filename = file.name
            if (fileMetadata.repath.isNullOrEmpty()) {
                this.relativePath = FilenameUtils.normalize(this.originRelativePath)
            } else {
                this.relativePath = FilenameUtils.normalize(fileMetadata.repath)
            }
            this.md5 = fileMetadata.md5
            this.extension = FilenameUtils.getExtension(file.name)
            this.filesize = fileMetadata.totalSize
            this.lastModified = Date(file.lastModified())
        }
        baseMapper.insert(entity)
    }

    override fun getUploadInfosByBatchId(batchId: String): MutableList<SysUploadInfo> {
        val condition = SysUploadInfo().apply { this.batchId = batchId }
        val ret = baseMapper.selectWOLogic(EntityWrapper(condition))
        ret.forEach {
            if (it.relativePath.isNullOrEmpty()) {
                it.url = FilenameUtils.normalize("/${it.filename}")
            } else {
                it.url = FilenameUtils.normalize("/${it.relativePath}/${it.filename}")
            }

        }
        return ret
    }

}
